==> cuber-0.27.tar.gz: cuber-0.27/cuber/cube.py <==
import abc
import cPickle as pickle
import os.path
import logging

import cache

logger = logging.getLogger(__name__)

class Cube(object):
    __metaclass__  = abc.ABCMeta

    checkpoints_dir = 'checkpoints/'

    @abc.abstractmethod
    def name(self):
        '''
            Unique name for cube and params. This name is key for cache.
        '''
        return

    def get(self, do_not_save_to_file = False):
        '''
            Checks if there is a cached verison and loads it.
            If there is no cached version, runs calcualtions via eval function.
            If you want to get cube's result, use only this function.
        '''
        # try load form memory
        cached, cached_data = cache.Cache().get(self.name())
        if cached:
            logger.info('Loaded from in-memory cache')
            return cached_data

        # try load from file, else evaluate result
        pickle_name = os.path.join(Cube.checkpoints_dir, '{}.pkl'.format(self.name()))
        logger.info('Pickle name: {}'.format(pickle_name))
        if not os.path.isfile(pickle_name):
            logger.info('Cache is not ok. Evaluating...')
            data = self.eval()

            if do_not_save_to_file:
                logger.info('Result is not saved because of flag do_not_save_to_file')
                return data

            logger.info('Writing cache')
            if not os.path.isdir(Cube.checkpoints_dir):
                os.makedirs(Cube.checkpoints_dir)
            with open(pickle_name, 'wb') as f:
                pickle.dump(data, f)
        else:
            logger.info('Cache is ok')
        logger.info('Loading from cache')
        with open(pickle_name, 'rb') as f:
            data = pickle.load(f)

        cache.Cache().add(self.name(), data)

        logger.info('Loaded')
        return data

    @abc.abstractmethod
    def eval(self):
        '''
            This method should contain meaningful calculations. It have to return dict with result.
        '''
        return

==> cuber-0.27.3.tar.gz: cuber-0.27.3/cuber/cube.py <==
import abc
import cPickle as pickle
import os.path
import logging

import cache

logger = logging.getLogger(__name__)

class Cube(object):
    __metaclass__  = abc.ABCMeta

    checkpoints_dir = 'checkpoints/'

    @abc.abstractmethod
    def name(self):
        '''
            Unique name for cube and params. This name is key for cache.
        '''
        return

    def get(self, do_not_save_to_file = False, disable_inmemory_cache = False):
        '''
            Checks if there is a cached verison and loads it.
            If there is no cached version, runs calcualtions via eval function.
            If you want to get cube's result, use only this function.
            TODO: refactor this code
        '''
        # try load form memory
        if not disable_inmemory_cache:
            cached, cached_data = cache.Cache().get(self.name())
            if cached:
                logger.info('Loaded from in-memory cache')
                return cached_data

        # try load from file, else evaluate result
        pickle_name = os.path.join(Cube.checkpoints_dir, '{}.pkl'.format(self.name()))
        logger.info('Pickle name: {}'.format(pickle_name))
        if not os.path.isfile(pickle_name):
            logger.info('Cache is not ok. Evaluating...')
            data = self.eval()

            if do_not_save_to_file:
                logger.info('Result is not saved because of flag do_not_save_to_file')
                return data

            logger.info('Writing cache')
            if not os.path.isdir(Cube.checkpoints_dir):
                os.makedirs(Cube.checkpoints_dir)
            with open(pickle_name, 'wb') as f:
                pickle.dump(data, f)
        else:
            logger.info('Cache is ok')
        logger.info('Loading from cache')
        with open(pickle_name, 'rb') as f:
            data = pickle.load(f)

        # ERROR: inmemory cache is not used if pickle chache disabled

        if not disable_inmemory_cache:
            cache.Cache().add(self.name(), data)

        logger.info('Loaded')
        return data

    @abc.abstractmethod
    def eval(self):
        '''
            This method should contain meaningful calculations. It have to return dict with result.
        '''
        return
